==> apache-kyuubi-1.9.4-source.tgz: apache-kyuubi-1.9.4-source/externals/kyuubi-jdbc-engine/src/test/scala/org/apache/kyuubi/engine/jdbc/postgresql/WithPostgreSQLEngine.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kyuubi.engine.jdbc.postgresql

import org.apache.kyuubi.config.KyuubiConf._
import org.apache.kyuubi.engine.jdbc.WithJdbcEngine

trait WithPostgreSQLEngine extends WithJdbcEngine with WithPostgreSQLContainer {

  override def withKyuubiConf: Map[String, String] = withContainers { container =>
    Map(
      ENGINE_SHARE_LEVEL.key -> "SERVER",
      ENGINE_JDBC_CONNECTION_URL.key -> container.jdbcUrl,
      ENGINE_JDBC_CONNECTION_USER.key -> container.username,
      ENGINE_JDBC_CONNECTION_PASSWORD.key -> container.password,
      ENGINE_TYPE.key -> "jdbc",
      ENGINE_JDBC_SHORT_NAME.key -> "postgresql",
      ENGINE_JDBC_DRIVER_CLASS.key -> container.driverClassName)
  }

}

==> apache-kyuubi-1.10.2-source.tgz: apache-kyuubi-1.10.2-source/externals/kyuubi-jdbc-engine/src/test/scala/org/apache/kyuubi/engine/jdbc/postgresql/WithPostgreSQLEngine.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kyuubi.engine.jdbc.postgresql

import org.apache.kyuubi.config.KyuubiConf._
import org.apache.kyuubi.config.KyuubiReservedKeys.KYUUBI_SESSION_USER_KEY
import org.apache.kyuubi.engine.jdbc.WithJdbcEngine

trait WithPostgreSQLEngine extends WithJdbcEngine with WithPostgreSQLContainer {

  override def withKyuubiConf: Map[String, String] = withContainers { container =>
    Map(
      ENGINE_SHARE_LEVEL.key -> "SERVER",
      ENGINE_JDBC_CONNECTION_URL.key -> container.jdbcUrl,
      ENGINE_JDBC_CONNECTION_USER.key -> container.username,
      ENGINE_JDBC_CONNECTION_PASSWORD.key -> container.password,
      ENGINE_TYPE.key -> "jdbc",
      ENGINE_JDBC_SHORT_NAME.key -> "postgresql",
      KYUUBI_SESSION_USER_KEY -> "kyuubi",
      ENGINE_JDBC_DRIVER_CLASS.key -> container.driverClassName)
  }

}
